#!/bin/bash
#
# This script compares two AppFS versions, example:
#
#   ./comp_app_version.sh 1.13beta2 1.13rc7
#
# It returns 1, if the first version number is lesser than the second one
# and with 0, if the first version number is greater or equal to the second one given.
#
# VERSION=2
# CHANGES="added support for service-packs"

function comp_vers {

	old=${1}
	new=${2}

	if [ -z "${old}" ] || [ -z ${new} ]; then
		return -1
	fi

	# get base version
	old_base=$(expr match "${old}" "\([0-9\.]*\)")
	new_base=$(expr match "${new}" "\([0-9\.]*\)")

	old_dot=$(expr match "${old_base}" ".*\.\([0-9]\{1,10\}\)")
	new_dot=$(expr match "${new_base}" ".*\.\([0-9]\{1,10\}\)")

	old_int="${old_base}"
	new_int="${new_base}"

	if [ ${#old_dot} -eq 1 ]; then
		old_int="${old_base}0"
	fi
	if [ ${#new_dot} -eq 1 ]; then
		new_int="${new_base}0"
	fi

	old_int=${old_int//\./}
	new_int=${new_int//\./}

	# check if base version is lower than new one
	if [ "${old_int}" -lt "${new_int}" ]; then
		return 1
	elif [ "${old_int}" -gt "${new_int}" ]; then
		return 0
	fi

	# get patch type
	old_type=$(expr match "${old}" ".*\(sp\|rc\|beta\)")
	new_type=$(expr match "${new}" ".*\(sp\|rc\|beta\)")

	# get patch level
	if [ ! -z "${old_type}" ]; then
		old_subv=$(expr match "${old}" ".*${old_base}-${old_type}\([0-9]*\)")
	fi

	if [ ! -z "${new_type}" ]; then
		new_subv=$(expr match "${new}" ".*${new_base}-${new_type}\([0-9]*\)")
	fi

	# check patch type
	if [ -z "${old_type}" ]; then
		case "${new_type}" in
			sp|rc)
				return 1
				;;
		esac
	fi

	case "${old_type}" in
		sp)
			case "${new_type}" in
				sp)
					if [ "${old_subv}" -lt "${new_subv}" ]; then
						return 1
					fi
					;;
			esac

			;;
		rc)
			case "${new_type}" in
				sp)
					return 1
					;;
				rc)
					if [ "${old_subv}" -lt "${new_subv}" ]; then
						return 1
					fi
					;;
			esac
			;;
		beta)
			if [ -z "${new_type}" ]; then
				return 1
			fi

			case "${new_type}" in
				rc|sp)
					return 1
					;;
				beta)
					if [ "${old_subv}" -lt "${new_subv}" ]; then
						return 1
					fi
					;;
			esac
			;;
	esac

	return 0
}

function comp_test {

	refv=${1}
	seqv=${2}

	tests="${refv} ${seqv}"

	for a in ${tests}; do
		comp_vers ${refv} ${a}
		if [ ${?} -eq 1 ]; then
			echo "${refv} needs to be updated to ${a}"
		else
			echo "${refv} needs NOT to be updated to ${a}"
		fi
	done
}

#comp_test "1.13rc8" "1.0 1.10rc1 1.11beta5 1.13beta2 1.13rc10 1.15 1.20 2.0 2.0beta1 2.0rc1 2.0beta2 2.2 2.2sp1"
#comp_test "2.2beta2" "1.0 1.10rc1 1.11beta5 1.13beta2 1.13rc10 1.15 1.20 2.0 2.0beta1 2.0rc1 2.0beta2 2.2 2.2sp1"
#comp_test "2.2rc2" "1.0 1.10rc1 1.11beta5 1.13beta2 1.13rc10 1.15 1.20 2.0 2.0beta1 2.0rc1 2.0beta2 2.2 2.2sp1"
#comp_test "2.2" "1.0 1.10rc1 1.11beta5 1.13beta2 1.13rc10 1.15 1.20 2.0 2.0beta1 2.0rc1 2.0beta2 2.2sp1"
#comp_test "2.2sp1" "1.0 1.10rc1 1.11beta5 1.13beta2 1.13rc10 1.15 1.20 2.0 2.0beta1 2.0rc1 2.0beta2 2.2 2.2sp2"
#comp_test "2.2sp2" "1.0 1.10rc1 1.11beta5 1.13beta2 1.13rc10 1.15 1.20 2.0 2.0beta1 2.0rc1 2.0beta2 2.2 2.2sp1"
#comp_test "2.2-sp1" "2.2-sp1 2.2-sp2"

comp_vers ${1} ${2}
exit ${?}
